package Echiquier;

import Echiquier.Piece.*;

import java.util.Scanner;

public class IHM {
    private Echiquier echiquier;
    private Case[][] table;

    public IHM(Echiquier echiquier){
        this.echiquier = echiquier;
        this.table = this.echiquier.getTable();
        affichage();

        menu();
    }

    private void affichage(){
        //afficher la numero de colonne
        for(int tmpcol=0; tmpcol < Echiquier.MAXCOL; tmpcol++) {
            System.out.print("  " + tmpcol);
        }
        System.out.println();

        //afficher la table de l'echiquier
        for(int lig=0; lig < Echiquier.MAXLIG; lig++){
            //afficher la separation de ligne
            System.out.print("  ");
            for(int tmplig=0; tmplig < Echiquier.MAXCOL; tmplig++) {
                System.out.print("---");
            }
            System.out.println();

            //afficher la numero de ligne
            System.out.print(lig);
            for(int col=0; col < Echiquier.MAXCOL; col++){
                //afficher la separation de colonne
                System.out.print("|");

                //afficher de la symbole de piece
                if(table[lig][col].estEuPiece()){
                    Piece piece = table[lig][col].getPiece();
                    if(piece.getClass() == Pion.class ){
                        System.out.print("P");
                    }
                    if(piece.getClass() == Cavalier.class){
                        System.out.print("C");
                    }
                    if(piece.getClass() == Dame.class){
                        System.out.print("D");
                    }
                    if(piece.getClass() == Fou.class){
                        System.out.print("F");
                    }
                    if(piece.getClass() == Roi.class){
                        System.out.print("R");
                    }
                    if(piece.getClass() == Tour.class){
                        System.out.print("T");
                    }

                    //affichier la color du joueur
                    if(piece.getColorJoueur() == ColorJoueur.NOIR){
                        System.out.print("N");
                    }
                    else {
                        System.out.print("B");
                    }
                }
                //afficher la vide case
                else{
                    System.out.print("  ");
                }
            }
            //afficher la dernier separation de colonne
            System.out.println("|");
        }
    }

    private void menu(){
        Case caseDepart = null;
        Case caseArrive = null;
        while(true){
            //recupperer le case que le joueur veut bouger
            try {
                caseDepart = saisirString("Déplacement d'une pièce de (la position de case diviser par ':' ou ','): ");
                caseArrive = saisirString("vers(la position de case diviser par ':' ou ',') : ");

                echiquier.deplace(caseDepart,caseArrive);
                affichage();
            }catch (EchiquierException e){
                System.out.println(e.getMessage());
            }
        }
    }

    private Case saisirString(String message){
        System.out.println(message);
        String valeur = "";

        Case unCase = null;
        try{
            //Saisire les valeurs
            Scanner sc = new Scanner(System.in);
            valeur = sc.nextLine();

            String[] divise = valeur.split("[:,;]");

            //Si l'entre n'est pas deux entiers
            if(divise.length != 2){
                throw new EchiquierException("La position drois est deux value(un ligne et un colone) qui divise par ':' ou ',' ");
            }

            int col = Integer.parseInt(divise[1].trim());
            int lig = Integer.parseInt(divise[0].trim());

            //Si le ligne est superieur à la ligne maximum
            if(lig >= Echiquier.MAXLIG){
                throw new EchiquierException("La ligne droit inférieur à " + Echiquier.MAXLIG);
            }

            //Si le colonne est superieur à la colonne maximum
            if(col >= Echiquier.MAXCOL){
                throw new EchiquierException("La colonne droit inférieur à " + Echiquier.MAXCOL);
            }

            unCase = new Case(lig, col);
        }catch (EchiquierException e){
            System.out.println(e.getMessage());
            saisirString(message);
        }

        return unCase;
    }
}
